import zmq
import time
import sys
import google.protobuf.json_format
#port = "1234"

def Send_Response(port):
    ontext = zmq.Context()
    socket = context.socket(zmq.REP)
    socket.bind("tcp://*:%s" % port)
 

    while True:
        #  Wait for next request from client
        protobuf_message = socket.recv_pyobj()
        print ("Received request: {}".format(protobuf_message))
        #  Covert message to json
        json_string = google.protobuf.json_format.MessageToJson(protobuf_message)
        #  Try to change the protobuf_message value
        protobuf_message.id='Stanly'
        socket.send_pyobj(protobuf_message)
        #time.sleep (1)  
    return True


import google.protobuf.json_format
import test_pb2
import json
import zmq
import sys

def __init__(self):
    jsonData = json.dumps({ "id":"John", "timestamp":"90", "lang":"50" })
    message = test_pb2.test()
    print("message:",message)
    protobuf_message = google.protobuf.json_format.Parse(jsonData,message, ignore_unknown_fields=False)
    print("protobuf_message:",protobuf_message)
    #test_ob=test_pb2.test()
    #print(test_ob.SerializeToString())

#port = "1234"
def Send_Request(port):
    jsonData = json.dumps({ "id":"John", "timestamp":"90", "lang":"80" })
    message = test_pb2.test()
    print("message:",message)
    protobuf_message = google.protobuf.json_format.Parse(jsonData,message, ignore_unknown_fields=False)
    print("protobuf_message:",protobuf_message)
    context = zmq.Context()
    print ("Connecting to server...")
    socket = context.socket(zmq.REQ)
    socket.connect ("tcp://localhost:%s" % port)

    for i in range(1):
        print ("Sending request {}".format(protobuf_message))
        socket.send_pyobj(protobuf_message)
            #  Get the reply.
        message = socket.recv_pyobj()
        print ("Received reply ", "[", message,"]")       
    return  ("Received reply ", "[", message,"]") 




from setuptools import setup
 

 
# specify requirements of your package here
REQUIREMENTS = ['zmq']
 
# some more details
CLASSIFIERS = [
    'Programming Language :: Python :: 3.5',
    ]
 
# calling the setup function 
setup(name='myzeromq',
      version='0.0.3',
      description='A request and response by using port',
      url='https://github.com/arockiastanlya/myzeromq',
      author='arockia stanly a',
      author_email='stanly499@gmail.com',
      packages=['zeromq'],
      classifiers=CLASSIFIERS,
      install_requires=REQUIREMENTS
      )